@@ -751,11 +751,11 @@ test_that("fit", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- logistic4_new(x, y, w, c(0, 1, 1, 1), max_iter, NULL, NULL)
@@ -767,11 +767,11 @@ test_that("fit", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -826,11 +826,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -846,11 +846,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -866,11 +866,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -925,11 +925,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -945,11 +945,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -965,11 +965,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1024,11 +1024,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1044,11 +1044,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1064,11 +1064,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1120,11 +1120,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- logistic4_new(x, y, w, c(0, 1, 1, 1), max_iter, NULL, NULL)
@@ -1136,11 +1136,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1195,11 +1195,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1215,11 +1215,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1235,11 +1235,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1294,11 +1294,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1314,11 +1314,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1334,11 +1334,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1393,11 +1393,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1413,11 +1413,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1433,11 +1433,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1705,23 +1705,3 @@ test_that("naac: increasing", {
   )
   expect_equal(naac(result, xlim = c(10, 15), ylim = c(0.3, 0.7)), 0.0)
 })
-
-test_that("curve_variance", {
-  x <- ltd$D$x
-  y <- ltd$D$y
-  w <- ltd$D$w
-
-  true_value <- c(
-    0.00051952654980924691, 0.00046539954498407387, 0.00087483729653211866
-  )
-
-  result <- drda(y ~ x, weights = w, mean_function = "logistic4")
-
-  xx <- c(-10, 1, 25)
-
-  vv <- curve_variance(result, xx)
-
-  expect_type(vv, "double")
-  expect_length(vv, length(xx))
-  expect_equal(vv, true_value)
-})
