@@ -758,11 +758,11 @@ test_that("fit", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic4_new(x, y, w, c(0, 1, 1, 1), max_iter, NULL, NULL)
@@ -774,11 +774,11 @@ test_that("fit", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -833,11 +833,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -853,11 +853,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -873,11 +873,11 @@ test_that("fit_constrained: inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -931,11 +931,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -951,11 +951,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -971,11 +971,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1029,11 +1029,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1049,11 +1049,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1069,11 +1069,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1125,11 +1125,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic4_new(x, y, w, c(0, 1, 1, 1), max_iter, NULL, NULL)
@@ -1141,11 +1141,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1200,11 +1200,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1220,11 +1220,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1240,11 +1240,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1298,11 +1298,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1318,11 +1318,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1338,11 +1338,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1396,11 +1396,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1416,11 +1416,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1436,11 +1436,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 2)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
