@@ -950,8 +950,8 @@ test_that("fit", {
   expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic5_new(x, y, w, c(0, 1, 1, 1, 1), max_iter, NULL, NULL)
@@ -966,8 +966,8 @@ test_that("fit", {
   expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1024,8 +1024,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1044,8 +1044,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1064,8 +1064,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1121,11 +1121,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1141,11 +1141,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1161,11 +1161,11 @@ test_that("fit_constrained: equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1221,11 +1221,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1241,11 +1241,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1261,11 +1261,11 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1318,11 +1318,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic5_new(
@@ -1336,11 +1336,11 @@ test_that("fit (weighted)", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1396,11 +1396,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1416,11 +1416,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1436,11 +1436,11 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 5)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1496,11 +1496,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1516,11 +1516,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1536,11 +1536,11 @@ test_that("fit_constrained (weighted): equalities", {
   expect_true(result$converged)
   expect_false(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1596,11 +1596,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1616,11 +1616,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1636,11 +1636,11 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_true(result$converged)
   expect_true(result$constrained)
   expect_equal(result$estimated, estimated)
-  expect_equal(result$coefficients, theta)
+  expect_equal(result$coefficients, theta, tolerance = 1.0e-6)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 3)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
